# Fluffy Funicular
Experimental CSAF envelope and body profile validator.

Available on [PyPI as csaf-lint](https://pypi.org/project/csaf-lint/) and
[hub.docker.com as shagen/csaf-lint](https://hub.docker.com/r/shagen/csaf-lint)

## Status
Experimental.

## Random Statements

Cascaded shape schema validation via russian doll design? Maybe.

Practical validation should expose the most convenient structure for stacked profiles (always adding not subtracting).

Read the source, Lucy!
